module.exports = defineTest({
	description: 'allows export { x as y }'
});
